@@ -5,6 +5,7 @@ from .client import Client
 from .image import Image, PlatformImage, UnavailableImagePlatformError, UnexpectedImageManifestError
 from .manifest import (
     ImageConfig,
+    ImageHistoryItem,
     InvalidPlatformNameError,
     LegacyManifest,
     Manifest,
@@ -19,7 +20,7 @@ from .registry import Registry
 from .repository import LegacyImageRequestError, Repository
 
 
-__version__ = "1.0.0"
+__version__ = "1.2.0"
 
 
 __all__ = (
@@ -29,6 +30,7 @@ __all__ = (
     "DockerTokenAuthService",
     "Image",
     "ImageConfig",
+    "ImageHistoryItem",
     "InvalidPlatformNameError",
     "LegacyManifest",
     "LegacyImageRequestError",
